# ImageCrawler: Reddit 

## Purpose

Not an actual crawler.  
Returns generic URIs to [https://picsum.photos](https://picsum.photos).

## Config

### `with`

- the width of the image in pixels.
- type: integer

### `height`

- the height of the image in pixels.
- type: integer
